@@ -16,7 +16,7 @@ from .exceptions import (
 )
 
 
-def import_module(module: str) -> t.Callable:
+def import_module(module: str) -> t.Type:
     """Import the given module from a package"""
     try:
         if "." in module:
@@ -30,3 +30,12 @@ def import_module(module: str) -> t.Callable:
         return kallable
     except ImportError as e:
         raise MinosImportException("Error importing Package")
+
+
+def classname(cls: t.Type) -> str:
+    """Compute the given class full name.
+
+    :param cls: Target class.
+    :return: An string object.
+    """
+    return f"{cls.__module__}.{cls.__qualname__}"
